@@ -3,9 +3,10 @@ package Perl::Critic::Policy::PreferredModules;
 use strict;
 use warnings;
 
-use Perl::Critic::Utils qw{ :severities :classification :ppi $SEVERITY_MEDIUM $TRUE $FALSE };
 use parent 'Perl::Critic::Policy';
 
+use Perl::Critic::Utils qw{ :severities :classification :ppi $SEVERITY_MEDIUM $TRUE $FALSE };
+
 use Perl::Critic::Exception::AggregateConfiguration ();
 use Perl::Critic::Exception::Configuration::Generic ();
 
@@ -22,7 +23,6 @@ sub supported_parameters {
 }
 
 use constant default_severity => $SEVERITY_MEDIUM;
-use constant default_themes   => qw{ bugs };
 use constant applies_to       => 'PPI::Statement::Include';
 
 use constant optional_config_attributes => qw{ prefer reason };
@@ -30,10 +30,12 @@ use constant optional_config_attributes => qw{ prefer reason };
 sub initialize_if_enabled {
     my ( $self, $config ) = @_;
 
-    my $cfg_file = $config->get('config');
+    my $cfg_file = $config->get('config') // '';
     $cfg_file =~ s{^~}{$ENV{HOME}};
 
-    return $self->_parse_config($cfg_file) ? $TRUE : $FALSE;
+    $self->{_is_enabled} = !! $self->_parse_config($cfg_file);
+
+    return $TRUE;
 }
 
 sub _add_exception {
@@ -54,7 +56,7 @@ sub _parse_config {
     my ( $self, $cfg_file ) = @_;
 
     if ( !length $cfg_file ) {
-        return $self->_add_exception(q['config' is not set for policy.]);
+        return;
     }
 
     if ( !-e $cfg_file ) {
@@ -96,6 +98,7 @@ sub _parse_config {
 sub violates {
     my ( $self, $elem ) = @_;
 
+    return () unless $self->{_is_enabled};
     return () unless $elem;
 
     my $module = $elem->module;
@@ -127,25 +130,24 @@ Perl::Critic::Policy::PreferredModules
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
-Every project could have its own rules for preferring some specific packages 
-over some others.
+Every project has its own rules for preferring specific packages over others.
 
-This Policy tries to be `non opiniated` and let the use customize the modules
-preference list and provide a reason at the same time.
+This Policy tries to be `un-opinionated` and let the user provide a module
+preferences with an explanation and/or suggested alternative.
 
 =head1 NAME
 
-Perl::Critic::Policy::PreferredModules - Custom package recommendations
+Perl::Critic::Policy::PreferredModules - Provide custom package recommendations
 
 =head1 MODULES
 
 =head1 CONFIGURATION
 
-To use L<Perl::Critic::Policy::PreferredModules> you have first to enable itin your
+To use L<Perl::Critic::Policy::PreferredModules> you have first to enable it in your
  F<.perlcriticrc> file by providing a F<preferred_modules.ini> configuration file:
 
     [PreferredModules]
@@ -155,18 +157,18 @@ To use L<Perl::Critic::Policy::PreferredModules> you have first to enable itin y
 
 The  F<preferred_modules.ini> file is using the L<Config::INI> format and can looks like this
 
-    [Do::Not::Recommend]
+    [Do::Not::Use]
     prefer = Another::Package
-    reason = Please prefer using Another::Package rather than package Do::Not::Recommend
+    reason = "Please use Another::Package rather than Do::Not::Use"
 
     [Avoid::Using::This]
     [And::Also::That]
+
+    [No:Reason]
+    prefer=A::Better:Module
     
-    [No:Reasons]
-    prefer=X
-    
-    [OnlyReason]
-    reason="I'm trying to tell you to do not use it..."
+    [Only::Reason]
+    reason="If you use this module, a puppy might die."
 
 =head1 SEE ALSO
 
